Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(848)

Unified Diff: chrome/browser/history/download_database.h

Issue 11363222: Persist download interrupt reason, both target and current paths, and url_chain. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/history/download_database.h
diff --git a/chrome/browser/history/download_database.h b/chrome/browser/history/download_database.h
index f5e18bdfbbf052c255c5a7aec5f5884b0b4143b8..45fd78395c7f362aefa9be344fd39ed1cbb2fe58 100644
--- a/chrome/browser/history/download_database.h
+++ b/chrome/browser/history/download_database.h
@@ -42,8 +42,10 @@ class DownloadDatabase {
// to select the row in the database table to update.
bool UpdateDownload(const content::DownloadPersistentStoreInfo& data);
- // Update the path of one download. Returns true if successful.
- bool UpdateDownloadPath(const FilePath& path, DownloadID db_handle);
+ // Update the paths of one download. Returns true if successful.
+ bool UpdateDownloadPath(const FilePath& target_path,
+ const FilePath& current_path,
+ DownloadID db_handle);
// Fixes state of the download entries. Sometimes entries with IN_PROGRESS
// state are not updated during browser shutdown (particularly when crashing).
@@ -75,6 +77,10 @@ class DownloadDatabase {
// database. See http://crbug.com/140687
bool MigrateDownloadsState();
+ // Returns true if able to successful add the last interrupt reason and the
+ // two target paths to downloads.
+ bool MigrateReasonAndPaths();
+
// Creates the downloads table if needed.
bool InitDownloadTable();

Powered by Google App Engine
This is Rietveld 408576698